==> thrio-1.7.5.tar.gz: android/src/main/kotlin/com/hellobike/flutter/thrio/module/ModuleJsonDeserializer.kt <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 foxsofter
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

package com.hellobike.flutter.thrio.module

import android.content.Context
import com.hellobike.flutter.thrio.JsonDeserializer
import com.hellobike.flutter.thrio.VoidCallback
import com.hellobike.flutter.thrio.navigator.JsonDeserializers

interface ModuleJsonDeserializer {
    fun onJsonDeserializerRegister(context: Context) {

    }

    fun <T> registerJsonDeserializer(deserializer: JsonDeserializer<T>, clazz: Class<T>): VoidCallback {
        return JsonDeserializers.deserializers.registry(clazz.toString(), deserializer)
    }
}

==> thrio-2.0.4.tar.gz: android/src/main/kotlin/com/hellobike/flutter/thrio/module/ModuleJsonDeserializer.kt <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 foxsofter
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

package com.hellobike.flutter.thrio.module

import com.hellobike.flutter.thrio.JsonDeserializer
import com.hellobike.flutter.thrio.VoidCallback

interface ModuleJsonDeserializer {

    fun onJsonDeserializerRegister(moduleContext: ModuleContext) {
    }

    fun <T> registerJsonDeserializer(
        deserializer: JsonDeserializer<T>,
        clazz: Class<T>
    ): VoidCallback {
        return ModuleJsonDeserializers.deserializers.registry(clazz.toString(), deserializer)
    }
}
